#
# spec file for package python-google-auth-oauthlib
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-google-auth-oauthlib
Version:        1.2.0
Release:        2.2
Summary:        Google authentication library
License:        Apache-2.0
URL:            https://github.com/googleapis/google-auth-library-python-oauthlib
Source:         https://files.pythonhosted.org/packages/source/g/google-auth-oauthlib/google-auth-oauthlib-%{version}.tar.gz
# https://github.com/googleapis/google-auth-library-python-oauthlib/issues/207
Patch0:         python-google-auth-oauthlib-no-mock.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-google-auth >= 2.14.0
Requires:       python-requests-oauthlib >= 0.7.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-click
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module click >= 6.0.0}
BuildRequires:  %{python_module google-auth >= 1.0.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests-oauthlib >= 0.7.0}
# /SECTION
%python_subpackages

%description
This library provides oauthlib integration with google-auth.

%prep
%autosetup -p1 -n google-auth-oauthlib-%{version}
rm -rf docs
rm -rf tests/__pycache__/
rm -rf tests/*.pyc

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/google-oauthlib-tool
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative google-oauthlib-tool

%postun
%python_uninstall_alternative google-oauthlib-tool

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/google-oauthlib-tool
%{python_sitelib}/google_auth_oauthlib
%{python_sitelib}/google_auth_oauthlib-%{version}.dist-info

%changelog
* Thu Feb 29 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to autosetup macro.
* Sat Dec 16 2023 Dirk Müller <dmueller@suse.com>
- update to 1.2.0:
  * Add support for Python 3.12 (#318)
  * Use setuptools.find_namespace_packages (#321)
* Thu Oct  5 2023 Dirk Müller <dmueller@suse.com>
- update to 1.1.0:
  * Adding support to specify browser while launching browser to
    authention (#305) (1a9dca8), closes #303
  * Pass thru OAuth audience during
    InstalledAppFlow.run_local_server (#300) (fe08531)
  * Fix grammar with fetch_token docstring (#273) (b2e3688)
* Sun Jul  2 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Mon Apr  3 2023 pgajdos@suse.com
- python-six is not required
* Tue Mar  7 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.0.0
  * PKCE is enabled by default. (#269)
  * Change the library from preview to stable (#267)
  * Remove deprecated OOB code (1391486)
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to v0.8.0:
  * Add support for Python 3.11
  * Introduce granted scopes to credentials
* Mon Nov  7 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.7.1
  * Include updates to properties from Google Auth lib (#249)
- from version 0.7.0
  * **setup.py:** increase required google-auth version to >= 2.13.0 (f8a15f7)
- from version 0.6.0
  * Update to allow for 3PI credentials (#240)
  * Add timeout to run_local_server when waiting for response (#245)
  * Update readme to point to current docs url (#241)
- Refresh patches for new version
  * python-google-auth-oauthlib-no-mock.patch
- Update Requires from setup.py
* Wed Oct 12 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.5.3
  Bug Fixes
  * Pass port range from get_user_credentials to find_open_port
* Tue Sep 13 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.5.2
  * fix changelog header to consistent size (#204)
* Wed Jun  8 2022 pgajdos@suse.com
- do not require python-mock for build
- added patches
  fix https://github.com/googleapis/google-auth-library-python-oauthlib/issues/207
  + python-google-auth-oauthlib-no-mock.patch
* Wed Apr 13 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.5.1
  * avoid deprecated "out-of-band" authentication flow (#186)
- from version 0.5.0
  * deprecate OAuth out-of-band flow (#175)
- from version 0.4.6
  * remove dependency on `six` (#146), closes (#145)
* Fri Aug 20 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update 0.4.5:
  * fix links to installed app, client secrets docs (#86)
  * omit mention of Python 2.7 in 'CONTRIBUTING.rst' (#1127)
  * add Samples section to CONTRIBUTING.rst (#134)
  * release as 0.4.5 (#137)
- from version 0.4.4
  * add redirect_uri_trailing slash param to run_local_server (#111)
- from version 0.4.3
  * add `charset-utf-8` to response header (#104)
  * **deps:** add lower bounds to all dependencies (#99)
- from version 0.4.2
  * don't open browser if port is occupied (#92)
- Update BuildRequires from setup.py
* Tue May 26 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Tue Oct  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.4.1:
  * Don't auto-generate code_verifier by default. (#48)
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.4.0:
  * Add get_user_credentials function to get your user credentials (#40)
  * Add noxfile (#43)
  * Implement code verifier (PKCE) (#42)
  * Use actual server port in redirect_uri to allow automatic assignment (#33)
  * Fix links after repo move to googleapis (#41)
* Thu May  2 2019 Todd R <toddrme2178@gmail.com>
- Initial version
